Abstract Base Templates for Django
==================================
Basic structure for building reusable templates in Django.


Installation and Configuration
------------------------------
*TODO*


Usage
-----
*TODO*


Examples
--------
*TODO*
